# mosec

[![lint and test](https://github.com/mosecorg/mosec/actions/workflows/check.yml/badge.svg)](https://github.com/mosecorg/mosec/actions/workflows/check.yml)
[![Upload Python Package](https://github.com/mosecorg/mosec/actions/workflows/package.yml/badge.svg)](https://github.com/mosecorg/mosec/actions/workflows/package.yml)

Model Serving made Efficient in the Cloud.
